==> nmsg-0.5.13.tar.gz: nmsg-0.5.13/nmsg/isc/linkpair.c <==
/* link pair nmsg message module */

/*
 * Copyright (c) 2008, 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#define MSGTYPE_LINKPAIR_ID	3
#define MSGTYPE_LINKPAIR_NAME	"linkpair"

/* Import. */

#include "linkpair.pb-c.c"

/* Data. */

struct nmsg_msgmod_field linkpair_fields[] = {
	{
		.type = nmsg_msgmod_ft_enum,
		.name = "type",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{
		.type = nmsg_msgmod_ft_string,
		.name = "src",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{
		.type = nmsg_msgmod_ft_string,
		.name = "dst",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{ .type = nmsg_msgmod_ft_mlstring,	.name = "headers"	},
	NMSG_MSGMOD_FIELD_END
};

/* Export. */

struct nmsg_msgmod_plugin nmsg_msgmod_ctx = {
	.msgver		= NMSG_MSGMOD_VERSION,
	.vendor		= NMSG_VENDOR_ISC,
	.msgtype	= { MSGTYPE_LINKPAIR_ID, MSGTYPE_LINKPAIR_NAME },

	.pbdescr	= &nmsg__isc__linkpair__descriptor,
	.fields		= linkpair_fields
};

/*! \file nmsg/isc/linkpair.c
 * \brief ISC "linkpair" message type.
 *
 * This message type is meant to carry information about links between webpages.
 *
 * <b> linkpair message fields.</b>

<table>

<tr>
<td><b> Name </b></td>
<td><b> Type </b></td>
<td><b> Required </b></td>
<td><b> Repeated </b></td>
<td><b> Description </b></td>
</tr>

<tr>
<td> type </b></td>
<td> enum Linktype </td>
<td> yes </td>
<td> no </td>
<td> Type of link pair. </td>
</tr>

<tr>
<td> src </td>
<td> string </td>
<td> yes </td>
<td> no </td>
<td> URI of source page. </td>
</tr>

<tr>
<td> dst </td>
<td> string </td>
<td> yes </td>
<td> no </td>
<td> URI of destination page. </td>
</tr>

<tr>
<td> headers </td>
<td> multi-line string </td>
<td> no </td>
<td> no </td>
<td> HTTP response headers of destination page. </td>
</tr>

</table>

 * <b>enum Linktype values.</b>

<table>

<tr>
<td><b> Name </b></td>
<td><b> Value </b></td>
<td><b> Description </b></td>
</tr>

<tr>
<td> anchor </td>
<td> 0 </td>
<td> link created by an &lt;A HREF&gt; tag </td>
</tr>

<tr>
<td> redirect </td>
<td> 1 </td>
<td> link created by an HTTP redirect </td>
</tr>

</table>
 */

==> nmsg-0.6.6.tar.gz: nmsg-0.6.6/nmsg/isc/linkpair.c <==
/* link pair nmsg message module */

/*
 * Copyright (c) 2008, 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* Import. */

#include "linkpair.pb-c.c"

/* Data. */

struct nmsg_msgmod_field linkpair_fields[] = {
	{
		.type = nmsg_msgmod_ft_enum,
		.name = "type",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{
		.type = nmsg_msgmod_ft_string,
		.name = "src",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{
		.type = nmsg_msgmod_ft_string,
		.name = "dst",
		.flags = NMSG_MSGMOD_FIELD_REQUIRED
	},
	{ .type = nmsg_msgmod_ft_mlstring,	.name = "headers"	},
	NMSG_MSGMOD_FIELD_END
};

/* Export. */

struct nmsg_msgmod_plugin nmsg_msgmod_ctx = {
	.msgver		= NMSG_MSGMOD_VERSION,
	.vendor		= NMSG_VENDOR_ISC,
	.msgtype	= { NMSG_VENDOR_ISC_LINKPAIR_ID, NMSG_VENDOR_ISC_LINKPAIR_NAME },

	.pbdescr	= &nmsg__isc__linkpair__descriptor,
	.fields		= linkpair_fields
};

/*! \file nmsg/isc/linkpair.c
 * \brief ISC "linkpair" message type.
 *
 * This message type is meant to carry information about links between webpages.
 *
 * <b> linkpair message fields.</b>

<table>

<tr>
<td><b> Name </b></td>
<td><b> Type </b></td>
<td><b> Required </b></td>
<td><b> Repeated </b></td>
<td><b> Description </b></td>
</tr>

<tr>
<td> type </b></td>
<td> enum Linktype </td>
<td> yes </td>
<td> no </td>
<td> Type of link pair. </td>
</tr>

<tr>
<td> src </td>
<td> string </td>
<td> yes </td>
<td> no </td>
<td> URI of source page. </td>
</tr>

<tr>
<td> dst </td>
<td> string </td>
<td> yes </td>
<td> no </td>
<td> URI of destination page. </td>
</tr>

<tr>
<td> headers </td>
<td> multi-line string </td>
<td> no </td>
<td> no </td>
<td> HTTP response headers of destination page. </td>
</tr>

</table>

 * <b>enum Linktype values.</b>

<table>

<tr>
<td><b> Name </b></td>
<td><b> Value </b></td>
<td><b> Description </b></td>
</tr>

<tr>
<td> anchor </td>
<td> 0 </td>
<td> link created by an &lt;A HREF&gt; tag </td>
</tr>

<tr>
<td> redirect </td>
<td> 1 </td>
<td> link created by an HTTP redirect </td>
</tr>

</table>
 */
